@@ -429,7 +429,7 @@ class Project {
     inflateContextMenuItems(menu) {
         var self = this;
         if (this.title == null && this.note != null) {
-            addContextMenuOption(menu, "", "Set title", () => {self.inflateTitleInput(self.container.querySelector(".project-header .project-title"))});
+            addContextMenuOption(menu, "ri-input-field", "Set title", () => {self.inflateTitleInput(self.container.querySelector(".project-header .project-title"))});
         }
         if (this.note == null) {
             addContextMenuOption(menu, "ri-sticky-note-line", "Bind note", () => {self.openNoteDialog()});
@@ -439,7 +439,7 @@ class Project {
         addContextMenuOption(menu, "ri-pencil-fill", "Edit in admin", () => {
             window.location.href = URL_ADMIN_PROJECT_CHANGE + this.id;
         });
-        addContextMenuOption(menu, "", "Status", () => {self.openStatusDialog()});
+        addContextMenuOption(menu, "ri-checkbox-circle-line", "Status", () => {self.openStatusDialog()});
         addContextMenuOption(menu, "ri-delete-bin-line", "Delete", () => {self.delete()});
     }
 
@@ -606,6 +606,12 @@ class TemporaryProject extends Project {
         let titleString = input.value.trim();
         let title = titleString.trim();
         if (title == "") title = null;
+        if (title == null) {
+            if (!(confirm("Create project with no title?"))) {
+                inflateProjects(this.parentContainer);
+                return;
+            }
+        }
         var self = this;
         apiPost("create-project", {}, (data) => {
             projects[data.project.id] = new Project(self.parentContainer, data.project, self.forceExpand);
